@@ -33,14 +33,14 @@ class dataTransfer():
         """Saves AWS credentials for boto3 client
         """
         #need to enter your own AWS credentials & path here:
-        filename = "C:/Users/ccrescas/Python/TransferData/aws_credentials.json"
+        filename = "C:/Users/ccrescas/Python/TransferData/credentials.json"
 
         with open(filename, 'r') as f:
-            aws_credentials = json.load(f)
+            credentials = json.load(f)
 
-        self.ACCESS_KEY = aws_credentials['ACCESS_KEY']
-        self.SECRET_KEY = aws_credentials['SECRET_KEY']
-        self.bucket = aws_credentials['bucket']
+        self.ACCESS_KEY = credentials['ACCESS_KEY']
+        self.SECRET_KEY = credentials['SECRET_KEY']
+        self.bucket = credentials['bucket']
 
         self.s3 = boto3.client('s3', aws_access_key_id=self.ACCESS_KEY,
                             aws_secret_access_key=self.SECRET_KEY)
